@@ -3,11 +3,13 @@ package Test::Alien::CPP;
 use strict;
 use warnings;
 use 5.008001;
-use Test::Alien 0.95 ();
+use ExtUtils::CppGuess;
+use Test::Alien 1.00 ();
+use Text::ParseWords qw( shellwords );
 use base qw( Exporter );
 
 # ABSTRACT: Testing tools for Alien modules for projects that use C++
-our $VERSION = '0.96'; # VERSION
+our $VERSION = '0.98'; # VERSION
 
 
 our @EXPORT = @Test::Alien::EXPORT;
@@ -21,19 +23,36 @@ sub xs_ok
   $cb = pop if defined $_[-1] && ref $_[-1] eq 'CODE';
   my($xs, $message) = @_;
 
-  $xs = { xs => $xs } unless ref $xs;
-  $xs->{pxs}->{'C++'} = 1;
-  $xs->{cbuilder_compile}->{'C++'} = 1;
-  
-  if($Test::Alien::VERSION >= 0.96)
+  if(ref($xs))
   {
-    $xs->{c_ext} = 'cpp';
+    my %xs = %$xs;
+    $xs = \%xs;
   }
   else
   {
-    $xs->{cpp} = 1;
+    $xs = { xs => $xs } unless ref $xs;
   }
-  
+  $xs->{pxs}->{'C++'} = 1;
+  $xs->{c_ext} = 'cpp';
+
+  my %stage = (
+    extra_compiler_flags => 'cbuilder_compile',
+    extra_linker_flags   => 'cbuilder_link',
+  );
+
+  my %cppguess = ExtUtils::CppGuess->new->module_build_options;
+  foreach my $name (qw( extra_compiler_flags extra_linker_flags ))
+  {
+    next unless defined $cppguess{$name};
+    my @new = ref($cppguess{$name}) eq 'ARRAY' ? @{ delete $cppguess{$name} } : shellwords(delete $cppguess{$name});
+    my @old = do {
+      my $value = delete $xs->{$stage{$name}}->{$name};
+      ref($value) eq 'ARRAY' ? @$value : shellwords($value);
+    };
+    $xs->{$stage{$name}}->{$name} = [@new, @old];
+  }
+  warn "extra Module::Build option: $_" for keys %cppguess;
+
   $cb ? Test::Alien::xs_ok($xs, $message, $cb) : Test::Alien::xs_ok($xs, $message);
 }
 
@@ -51,7 +70,7 @@ Test::Alien::CPP - Testing tools for Alien modules for projects that use C++
 
 =head1 VERSION
 
-version 0.96
+version 0.98
 
 =head1 SYNOPSIS
 
